@@ -6,7 +6,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
   'Dist::Zilla::Role::PluginBundle::Config::Slicer',
   'Dist::Zilla::Role::PluginBundle::PluginRemover';
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 sub configure {
 	my $self = shift;
@@ -61,10 +61,10 @@ sub configure {
 		[CopyFilesFromBuild => { copy => \@from_build }]);
 	# @Basic, with some modifications
 	$self->add_plugins(qw/PruneCruft ManifestSkip MetaYAML MetaJSON
-		License ReadmeAnyFromPod ExtraTests ExecDir ShareDir/);
+		License ReadmeAnyFromPod ExecDir ShareDir/);
 	$self->add_plugins([ExecDir => 'ScriptDir' => { dir => 'script' }]);
 	$self->add_plugins($installer);
-	$self->add_plugins(qw/InstallGuide Manifest TestRelease ConfirmRelease/);
+	$self->add_plugins(qw/RunExtraTests InstallGuide Manifest TestRelease ConfirmRelease/);
 	$self->add_plugins($ENV{FAKE_RELEASE} ? 'FakeRelease' : 'UploadToCPAN');
 }
 
@@ -156,12 +156,12 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  [MetaJSON]
  [License]
  [ReadmeAnyFromPod]
- [ExtraTests]
  [ExecDir]
  [ExecDir / ScriptDir]
  dir = script
  [ShareDir]
  [MakeMaker]
+ [RunExtraTests]
  [InstallGuide]
  [Manifest]
  [TestRelease]
